==> dateparser_1.0.0.orig.tar.gz: dateparser-1.0.0/dateparser/data/date_translation_data/ko.py <==
info = {
    "name": "ko",
    "date_order": "YMD",
    "january": [
        "1월"
    ],
    "february": [
        "2월"
    ],
    "march": [
        "3월"
    ],
    "april": [
        "4월"
    ],
    "may": [
        "5월"
    ],
    "june": [
        "6월"
    ],
    "july": [
        "7월"
    ],
    "august": [
        "8월"
    ],
    "september": [
        "9월"
    ],
    "october": [
        "10월"
    ],
    "november": [
        "11월"
    ],
    "december": [
        "12월"
    ],
    "monday": [
        "월요일",
        "월"
    ],
    "tuesday": [
        "화요일",
        "화"
    ],
    "wednesday": [
        "수요일",
        "수"
    ],
    "thursday": [
        "목요일",
        "목"
    ],
    "friday": [
        "금요일",
        "금"
    ],
    "saturday": [
        "토요일",
        "토"
    ],
    "sunday": [
        "일요일",
        "일"
    ],
    "am": [
        "오전",
        "am"
    ],
    "pm": [
        "오후",
        "pm"
    ],
    "year": [
        "년"
    ],
    "month": [
        "월"
    ],
    "week": [
        "주"
    ],
    "day": [
        "일"
    ],
    "hour": [
        "시"
    ],
    "minute": [
        "분"
    ],
    "second": [
        "초"
    ],
    "relative-type": {
        "1 year ago": [
            "작년"
        ],
        "0 year ago": [
            "올해"
        ],
        "in 1 year": [
            "내년"
        ],
        "1 month ago": [
            "지난달"
        ],
        "0 month ago": [
            "이번 달"
        ],
        "in 1 month": [
            "다음 달"
        ],
        "1 week ago": [
            "지난주"
        ],
        "0 week ago": [
            "이번 주"
        ],
        "in 1 week": [
            "다음 주"
        ],
        "1 day ago": [
            "어제"
        ],
        "0 day ago": [
            "오늘"
        ],
        "in 1 day": [
            "내일"
        ],
        "0 hour ago": [
            "현재 시간"
        ],
        "0 minute ago": [
            "현재 분"
        ],
        "0 second ago": [
            "지금"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+)년 후"
        ],
        "\\1 year ago": [
            "(\\d+)년 전"
        ],
        "in \\1 month": [
            "(\\d+)개월 후"
        ],
        "\\1 month ago": [
            "(\\d+)개월 전"
        ],
        "in \\1 week": [
            "(\\d+)주 후"
        ],
        "\\1 week ago": [
            "(\\d+)주 전"
        ],
        "in \\1 day": [
            "(\\d+)일 후"
        ],
        "\\1 day ago": [
            "(\\d+)일 전"
        ],
        "in \\1 hour": [
            "(\\d+)시간 후"
        ],
        "\\1 hour ago": [
            "(\\d+)시간 전"
        ],
        "in \\1 minute": [
            "(\\d+)분 후"
        ],
        "\\1 minute ago": [
            "(\\d+)분 전"
        ],
        "in \\1 second": [
            "(\\d+)초 후"
        ],
        "\\1 second ago": [
            "(\\d+)초 전"
        ]
    },
    "locale_specific": {
        "ko-KP": {
            "name": "ko-KP"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser_1.2.0.orig.tar.gz: dateparser-1.2.0/dateparser/data/date_translation_data/ko.py <==
info = {
    "name": "ko",
    "date_order": "YMD",
    "january": [
        "1월"
    ],
    "february": [
        "2월"
    ],
    "march": [
        "3월"
    ],
    "april": [
        "4월"
    ],
    "may": [
        "5월"
    ],
    "june": [
        "6월"
    ],
    "july": [
        "7월"
    ],
    "august": [
        "8월"
    ],
    "september": [
        "9월"
    ],
    "october": [
        "10월"
    ],
    "november": [
        "11월"
    ],
    "december": [
        "12월"
    ],
    "monday": [
        "월",
        "월요일"
    ],
    "tuesday": [
        "화",
        "화요일"
    ],
    "wednesday": [
        "수",
        "수요일"
    ],
    "thursday": [
        "목",
        "목요일"
    ],
    "friday": [
        "금",
        "금요일"
    ],
    "saturday": [
        "토",
        "토요일"
    ],
    "sunday": [
        "일",
        "일요일"
    ],
    "am": [
        "am",
        "오전"
    ],
    "pm": [
        "pm",
        "오후"
    ],
    "year": [
        "년"
    ],
    "month": [
        "월"
    ],
    "week": [
        "주"
    ],
    "day": [
        "일"
    ],
    "hour": [
        "시"
    ],
    "minute": [
        "분"
    ],
    "second": [
        "초"
    ],
    "relative-type": {
        "0 day ago": [
            "오늘"
        ],
        "0 hour ago": [
            "현재 시간"
        ],
        "0 minute ago": [
            "현재 분"
        ],
        "0 month ago": [
            "이번 달"
        ],
        "0 second ago": [
            "지금"
        ],
        "0 week ago": [
            "이번 주"
        ],
        "0 year ago": [
            "올해"
        ],
        "1 day ago": [
            "어제"
        ],
        "1 month ago": [
            "지난달"
        ],
        "1 week ago": [
            "지난주"
        ],
        "1 year ago": [
            "작년"
        ],
        "in 1 day": [
            "내일"
        ],
        "in 1 month": [
            "다음 달"
        ],
        "in 1 week": [
            "다음 주"
        ],
        "in 1 year": [
            "내년"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*)일 전"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*)시간 전"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*)분 전"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*)개월 전"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*)초 전"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*)주 전"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*)년 전"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*)일 후"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*)시간 후"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*)분 후"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*)개월 후"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*)초 후"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*)주 후"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*)년 후"
        ]
    },
    "locale_specific": {
        "ko-KP": {
            "name": "ko-KP"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
